import React, { useEffect, useRef, useState } from "react";
import Taro from "@tarojs/taro";
import { View, Image, Button, Canvas } from "@tarojs/components";
import Spin2 from "@/components/Spin/Spin2";
import { save2Album, base64ToFile } from "@/utils/image";
// import Poster from './Poster'
import useCanvas from "./useCanvas";
import "./style.scss";

export default props => {
  const { show, dataSource, onClose, onSuccess } = props;

  const [img, setImg] = useState();
  const [processing, setProcessing] = useState(false);

  const [canvasInited, setCanvasInited] = useState(false);

  const posterRender = useRef();

  useCanvas("canvas-broker-poster", fn => {
    posterRender.current = fn;
    setCanvasInited(true);
  });

  const Save = e => {
    e.stopPropagation();
    if (img) {
      save2Album(img).then(() => {
        Taro.showToast({ title: "保存成功", icon: "none" });
      });

    }
  };

  useEffect(() => {
    if (dataSource && canvasInited) {
      const getPoster = posterRender.current;
      setProcessing(true);
      getPoster(dataSource)
        .then(image => {
       
          base64ToFile(image.replace("data:image/jpeg;base64,", "")).then(
            tmpFile => {
              console.log(tmpFile, "tmpFiletmpFile");
              setImg(tmpFile);
            }
          );

          setProcessing(false);
        })
        .catch(() => {
          setProcessing(false);
        });
    }
  }, [dataSource, canvasInited]);

  return (
    <>
      {show && (
        <View className="container" onClick={() => onClose()}>
          <view className="centerLabel">
            <view>
              <view className="Img">
                {!processing ? (
                  <Image
                    src={img}
                    mode="scaleToFill"
                    className="centerLabel"
                    onClick={e => e.stopPropagation()}
                  />
                ) : (
                  <Spin2
                    className="centerLabel"
                    spinning={processing}
                    size={32}
                  />
                )}
              </view>
            </view>
            <view className="saveimg">
              <text onClick={Save}>保存到手机</text>
            </view>
          </view>
        </View>
      )}

      <View style={{ width: "1px", height: "1px", overflow: "hidden" }}>
        <Canvas
          type="2d"
          id="canvas-broker-poster"
          style={{ width: "1px", height: "1px" }}
        />
      </View>
    </>
  );
};
